#' Example data from Yang, Knoke (2001)
#'
#' A sociomatrix encoding tie strengths among five nodes, used 
#' for examples in Yang, S., Knoke, D. (2001) Social Networks 23(4):285-295
#'
#' @format a numeric matrix with 5 rows and 5 columns
#' 
#' @source <DOI: 10.1016/S0378-8733(01)00043-0>
"YangKnoke01"

#' Example data from Opsahl, Agneessens, Skvoretz (2010)
#' 
#' A sociomatrix encoding tie strengths among five nodes, used for examples in
#' Opsahl, Agneessens, Skvoretz (2010) Social Networks 32(2010):245-251
#' 
#' @format a numeric matrix with 5 rows and 5 columns
#' 
#' @source  <DOI:10.1016/j.socnet.2010.03.006>
"OpsahlEtAl10"

#' Example data for gretel
#' 
#' A sociomatrix encoding tie strengths among five nodes
#' 
#' @format a numeric matrix with 5 rows and 5 columns
#' 
#' @source  <DOI:10.1016/j.socnet.2010.03.006>
"BuchDarrah19"