# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' Find the shortest paths to other vertices
#' 
#' @param dist A matrix of distances between nodes
#' @param src An integer vertex ID 
#' @param node_costs a list of costs, in order, of all nodes represented in the 
#'     sociomatrix, all are assumed 0 if unspecified
#' @return A numeric vector, entry \emph{i} of which is the vertex immediately preceeding 
#'     vertex \emph{i} in the shortest path leading to \emph{i}. Full paths must be constructed
#'     recursively.
dijkstra_nodes <- function(dist, src, node_costs) {
    .Call(`_gretel_dijkstra_nodes`, dist, src, node_costs)
}

#' Find the shortest L-Inf norm paths to other vertices
#' 
#' @param dist A matrix of distances between nodes
#' @param src An integer vertex ID 
#' @return A numeric vector, entry \emph{i} of which is the vertex immediately preceeding 
#'   vertex \emph{i} in the shortest path leading to \emph{i}. Full paths must be constructed
#'   recursively.
dijkstra_inf <- function(dist, src) {
    .Call(`_gretel_dijkstra_inf`, dist, src)
}

